* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Obsolescence Risk Management Capabilities](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities)
  * Technology Obsolescence Risk Statuses and Views in …
